/*===================================================================================
 *                    Copyright(c) 2020 POSCO ICT
 *
 * Project            : workcenter-spi
 * Source File Name   : com.aworks.workcenter.spi.message.Message.java
 * Description        :
 * Author             : ddurung
 * Version            : 1.0.0
 * File Name related  :
 * Class Name related :
 * Created Date       : 2020. 4. 6.
 * Updated Date       : 2020. 4. 6.
 * Last modifier      : ddurung
 * Updated content    : 최초작성
 *
 *==================================================================================*/
package com.aworks.workcenter.spi.message;

/**
 * Message.java
 *
 * @author ddurung
 * @version 1.0.0
 * @since 2020. 4. 6.
 */
public class Message {

    public enum Type {
        NOTICE, ALERT
    }

    private final String sender;
    private final String receiver;
    private final Type type;
    private final String subject;
    private final String body;

    /**
     * Constructor
     *
     * @param sender the sender
     * @param receiver the receiver
     * @param type the type
     * @param subject the subject
     * @param body the body
     */
    public Message( String sender, String receiver, Type type, String subject, String body ) {
        this.sender = sender;
        this.receiver = receiver;
        this.type = type;
        this.subject = subject;
        this.body = body;
    }

    /**
     * Return the sender
     *
     * @return the sender
     */
    public String getSender() {
        return sender;
    }

    /**
     * Return the receiver
     *
     * @return the receiver
     */
    public String getReceiver() {
        return receiver;
    }

    /**
     * Return the type
     *
     * @return the type
     */
    public Type getType() {
        return type;
    }

    /**
     * Return the subject
     *
     * @return the subject
     */
    public String getSubject() {
        return subject;
    }

    /**
     * Return the body
     *
     * @return the body
     */
    public String getBody() {
        return body;
    }

}
